@@ -169,10 +169,6 @@ function configure_manila {
     fi
     sudo chown $STACK_USER $MANILA_CONF_DIR
 
-    if [[ -f $MANILA_DIR/etc/manila/policy.json ]]; then
-        cp -p $MANILA_DIR/etc/manila/policy.json $MANILA_CONF_DIR
-    fi
-
     # Set the paths of certain binaries
     MANILA_ROOTWRAP=$(get_rootwrap_location manila)
 
@@ -277,7 +273,7 @@ function configure_manila {
     iniset $MANILA_CONF DEFAULT enabled_share_backends $MANILA_ENABLED_BACKENDS
 
     if [ ! -f $MANILA_PATH_TO_PRIVATE_KEY ]; then
-        ssh-keygen -N "" -t rsa -f $MANILA_PATH_TO_PRIVATE_KEY;
+        ssh-keygen -N "" -t $MANILA_KEY_FORMAT -f $MANILA_PATH_TO_PRIVATE_KEY;
     fi
 
     iniset $MANILA_CONF DEFAULT manila_service_keypair_name $MANILA_SERVICE_KEYPAIR_NAME
@@ -313,7 +309,7 @@ function configure_manila {
     if [[ "$MANILA_ENFORCE_SCOPE" == True ]] ; then
         iniset $MANILA_CONF oslo_policy enforce_scope true
         iniset $MANILA_CONF oslo_policy enforce_new_defaults true
-        OS_CLOUD="devstack-system-admin"
+        OS_CLOUD="devstack-admin"
     fi
 }
 
@@ -521,13 +517,6 @@ function create_manila_accounts {
 # create_default_share_group_type - create share group type that will be set as default.
 function create_default_share_group_type {
 
-    # NOTE(gouthamr): manilaclient's shell doesn't support cloud profiles;
-    # OSC is the best approach here: https://review.opendev.org/805064, but,
-    # we need a temporary workaround to use legacy credentials while we wait
-    # for OSC support
-    # TODO(gouthamr): Remove workaround when we replace the commands below
-    # with OSC equivalents
-
     local type_exists=$( openstack --os-cloud $OS_CLOUD share group type list | grep " $MANILA_DEFAULT_SHARE_GROUP_TYPE " )
     if [[ -z $type_exists ]]; then
         openstack --os-cloud $OS_CLOUD share group type create $MANILA_DEFAULT_SHARE_GROUP_TYPE $MANILA_DEFAULT_SHARE_TYPE
@@ -785,9 +774,6 @@ function install_manila {
             fi
             check_nfs_kernel_service_state_ubuntu
         elif [ "$SHARE_DRIVER" == $MANILA_CONTAINER_DRIVER ]; then
-            # Remove workaround for https://launchpad.net/bugs/1876820 when
-            # container driver stops using "brctl"
-            install_package bridge-utils
             if is_ubuntu; then
                 echo "Installing docker...."
                 install_docker_ubuntu
