@@ -59,6 +59,9 @@ class ShareNetworkController(wsgi.Controller, wsgi.AdminActionsMixin):
         'status': set(constants.SHARE_NETWORK_STATUSES)
     }
 
+    def _get(self, *args, **kwargs):
+        return db_api.share_network_get(*args, **kwargs)
+
     def show(self, req, id):
         """Return data about the requested network info."""
         context = req.environ['manila.context']
@@ -391,6 +394,7 @@ class ShareNetworkController(wsgi.Controller, wsgi.AdminActionsMixin):
                 share_network = db_api.share_network_create(
                     context, share_network_values)
             except db_exception.DBError as e:
+                QUOTAS.rollback(context, reservations)
                 LOG.exception(e)
                 msg = "Could not create share network."
                 raise exc.HTTPInternalServerError(explanation=msg)
@@ -406,7 +410,8 @@ class ShareNetworkController(wsgi.Controller, wsgi.AdminActionsMixin):
                     context, share_network_subnet_values)
             except db_exception.DBError:
                 db_api.share_network_delete(context, share_network['id'])
-                msg = _('Could not create share network.')
+                QUOTAS.rollback(context, reservations)
+                msg = _('Could not create share network subnet.')
                 raise exc.HTTPInternalServerError(explanation=msg)
 
             QUOTAS.commit(context, reservations)
@@ -598,7 +603,7 @@ class ShareNetworkController(wsgi.Controller, wsgi.AdminActionsMixin):
         data = body['add_security_service_check']
         try:
             security_service = db_api.security_service_get(
-                context, data['security_service_id'])
+                context, data['security_service_id'], project_only=True)
         except KeyError:
             msg = "Malformed request body."
             raise exc.HTTPBadRequest(explanation=msg)
