@@ -305,6 +305,10 @@ class ShareServerNotReady(ManilaException):
                 "within %(time)s seconds.")
 
 
+class ShareServerBackendDetailsNotFound(NotFound):
+    message = _("Share server backend details does not exist.")
+
+
 class ServiceNotFound(NotFound):
     message = _("Service %(service_id)s could not be found.")
 
@@ -329,6 +333,10 @@ class HostBinaryNotFound(NotFound):
     message = _("Could not find binary %(binary)s on host %(host)s.")
 
 
+class TransferNotFound(NotFound):
+    message = _("Transfer %(transfer_id)s could not be found.")
+
+
 class InvalidReservationExpiration(Invalid):
     message = _("Invalid reservation expiration %(expire)s.")
 
@@ -489,6 +497,10 @@ class InvalidShare(Invalid):
     message = _("Invalid share: %(reason)s.")
 
 
+class InvalidAuthKey(Invalid):
+    message = _("Invalid auth key: %(reason)s")
+
+
 class ShareBusyException(Invalid):
     message = _("Share is busy with an active task: %(reason)s.")
 
@@ -527,6 +539,10 @@ class ShareSnapshotAccessExists(InvalidInput):
     message = _("Share snapshot access %(access_type)s:%(access)s exists.")
 
 
+class InvalidSnapshot(Invalid):
+    message = _("Invalid snapshot: %(reason)s")
+
+
 class InvalidSnapshotAccess(Invalid):
     message = _("Invalid access rule: %(reason)s")
 
@@ -543,6 +559,10 @@ class InvalidShareAccessType(Invalid):
     message = _("Invalid or unsupported share access type: %(type)s.")
 
 
+class DriverCannotTransferShareWithRules(ManilaException):
+    message = _("Driver failed to transfer share with rules.")
+
+
 class ShareBackendException(ManilaException):
     message = _("Share backend error: %(msg)s.")
 
@@ -1122,3 +1142,8 @@ class ZadaraVPSASnapshotManageFailed(ShareBackendException):
 
 class ZadaraServerNotFound(NotFound):
     message = _("Unable to find server object for initiator %(name)s")
+
+
+# Macrosan Storage driver
+class MacrosanBackendExeption(ShareBackendException):
+    message = _("Macrosan backend exception: %(reason)s")
