@@ -792,7 +792,7 @@ class QuotaEngine(object):
         if self.__driver:
             return self.__driver
         if not self._driver_cls:
-            self._driver_cls = CONF.quota_driver
+            self._driver_cls = CONF.quota.driver
         if isinstance(self._driver_cls, str):
             self._driver_cls = importutils.import_object(self._driver_cls)
         self.__driver = self._driver_cls
