@@ -30,6 +30,7 @@ from manila.share import configuration
 from manila.share import driver
 from manila.share.drivers.netapp.dataontap.client import api as netapp_api
 from manila.share.drivers.netapp.dataontap.client import client_cmode
+from manila.share.drivers.netapp.dataontap.client import client_cmode_rest
 from manila.share.drivers.netapp import options as na_opts
 from manila.share.drivers.netapp import utils as na_utils
 from manila.share import utils as share_utils
@@ -72,15 +73,27 @@ def get_backend_configuration(backend_name):
 
 def get_client_for_backend(backend_name, vserver_name=None):
     config = get_backend_configuration(backend_name)
-    client = client_cmode.NetAppCmodeClient(
-        transport_type=config.netapp_transport_type,
-        ssl_cert_path=config.netapp_ssl_cert_path,
-        username=config.netapp_login,
-        password=config.netapp_password,
-        hostname=config.netapp_server_hostname,
-        port=config.netapp_server_port,
-        vserver=vserver_name or config.netapp_vserver,
-        trace=na_utils.TRACE_API)
+    if config.netapp_use_legacy_client:
+        client = client_cmode.NetAppCmodeClient(
+            transport_type=config.netapp_transport_type,
+            ssl_cert_path=config.netapp_ssl_cert_path,
+            username=config.netapp_login,
+            password=config.netapp_password,
+            hostname=config.netapp_server_hostname,
+            port=config.netapp_server_port,
+            vserver=vserver_name or config.netapp_vserver,
+            trace=na_utils.TRACE_API)
+    else:
+        client = client_cmode_rest.NetAppRestClient(
+            transport_type=config.netapp_transport_type,
+            ssl_cert_path=config.netapp_ssl_cert_path,
+            username=config.netapp_login,
+            password=config.netapp_password,
+            hostname=config.netapp_server_hostname,
+            port=config.netapp_server_port,
+            vserver=vserver_name or config.netapp_vserver,
+            async_rest_timeout=config.netapp_rest_operation_timeout,
+            trace=na_utils.TRACE_API)
 
     return client
 
@@ -186,13 +199,14 @@ class DataMotionSession(object):
             source_share_obj)
 
         # 1. Create SnapMirror relationship
-        # TODO(ameade): Change the schedule from hourly to a config value
+        config = get_backend_configuration(dest_backend)
+        schedule = config.netapp_snapmirror_schedule
         dest_client.create_snapmirror_vol(src_vserver,
                                           src_volume_name,
                                           dest_vserver,
                                           dest_volume_name,
                                           relationship_type,
-                                          schedule='hourly')
+                                          schedule=schedule)
 
         # 2. Initialize async transfer of the initial data
         dest_client.initialize_snapmirror_vol(src_vserver,
@@ -305,7 +319,8 @@ class DataMotionSession(object):
                 source_vserver=source_vserver, dest_vserver=dest_vserver,
                 desired_attributes=['relationship-status', 'mirror-state']
             )[0]
-            if snapmirror.get('relationship-status') != 'quiesced':
+            if snapmirror.get('relationship-status') not in ['quiesced',
+                                                             'paused']:
                 raise exception.ReplicationException(
                     reason="Snapmirror relationship is not quiesced.")
 
@@ -316,7 +331,8 @@ class DataMotionSession(object):
                                              dest_vserver,
                                              clear_checkpoint=False)
 
-    def quiesce_then_abort(self, source_share_obj, dest_share_obj):
+    def quiesce_then_abort(self, source_share_obj, dest_share_obj,
+                           quiesce_wait_time=None):
         dest_volume, dest_vserver, dest_backend = (
             self.get_backend_info_for_share(dest_share_obj))
         dest_client = get_client_for_backend(dest_backend,
@@ -332,7 +348,9 @@ class DataMotionSession(object):
                                            dest_volume)
 
         config = get_backend_configuration(dest_backend)
-        retries = config.netapp_snapmirror_quiesce_timeout / 5
+        timeout = (
+            quiesce_wait_time or config.netapp_snapmirror_quiesce_timeout)
+        retries = int(timeout / 5) or 1
 
         @utils.retry(retry_param=exception.ReplicationException,
                      interval=5,
@@ -344,7 +362,8 @@ class DataMotionSession(object):
                 source_volume=src_volume, dest_volume=dest_volume,
                 desired_attributes=['relationship-status', 'mirror-state']
             )[0]
-            if snapmirror.get('relationship-status') != 'quiesced':
+            if snapmirror.get('relationship-status') not in ['quiesced',
+                                                             'paused']:
                 raise exception.ReplicationException(
                     reason="Snapmirror relationship is not quiesced.")
 
@@ -357,7 +376,8 @@ class DataMotionSession(object):
                                              dest_volume,
                                              clear_checkpoint=False)
 
-    def break_snapmirror(self, source_share_obj, dest_share_obj, mount=True):
+    def break_snapmirror(self, source_share_obj, dest_share_obj, mount=True,
+                         quiesce_wait_time=None):
         """Breaks SnapMirror relationship.
 
         1. Quiesce any ongoing snapmirror transfers
@@ -374,7 +394,8 @@ class DataMotionSession(object):
             source_share_obj)
 
         # 1. Attempt to quiesce, then abort
-        self.quiesce_then_abort(source_share_obj, dest_share_obj)
+        self.quiesce_then_abort(source_share_obj, dest_share_obj,
+                                quiesce_wait_time=quiesce_wait_time)
 
         # 2. Break SnapMirror
         dest_client.break_snapmirror_vol(src_vserver,
@@ -475,14 +496,14 @@ class DataMotionSession(object):
                                                        replica_vserver)
 
         # 3. create
-        # TODO(ameade): Update the schedule if needed.
         relationship_type = na_utils.get_relationship_type(is_flexgroup)
+        schedule = replica_config.netapp_snapmirror_schedule
         replica_client.create_snapmirror_vol(new_src_vserver,
                                              new_src_volume_name,
                                              replica_vserver,
                                              replica_volume_name,
                                              relationship_type,
-                                             schedule='hourly')
+                                             schedule=schedule)
 
         # 4. resync
         replica_client.resync_snapmirror_vol(new_src_vserver,
