@@ -37,7 +37,15 @@ netapp_connection_opts = [
     cfg.PortOpt('netapp_server_port',
                 help=('The TCP port to use for communication with the storage '
                       'system or proxy server. If not specified, Data ONTAP '
-                      'drivers will use 80 for HTTP and 443 for HTTPS.')), ]
+                      'drivers will use 80 for HTTP and 443 for HTTPS.')),
+    cfg.BoolOpt('netapp_use_legacy_client',
+                default=True,
+                help=('The ONTAP client used for retrieving and modifying '
+                      'data on the storage. The legacy client relies mostly '
+                      'on ZAPI calls, only using REST calls for SVM migrate '
+                      'feature. If set to False, the new REST client is used, '
+                      'which runs REST calls if supported, otherwise falls '
+                      'back to the equivalent ZAPI call.')), ]
 
 netapp_transport_opts = [
     cfg.StrOpt('netapp_transport_type',
@@ -176,7 +184,13 @@ netapp_provisioning_opts = [
                min=60,
                default=360,  # Default to six minutes
                help='Sets time in seconds to wait for a FlexGroup snapshot '
-                    'to not be busy with clones after splitting them.'), ]
+                    'to not be busy with clones after splitting them.'),
+    cfg.IntOpt('netapp_rest_operation_timeout',
+               min=60,
+               default=60,  # Default to one minutes
+               help='Sets maximum amount of time in seconds to wait for a '
+                    'synchronous ONTAP REST API operation to be completed.'),
+]
 
 netapp_cluster_opts = [
     cfg.StrOpt('netapp_vserver',
@@ -215,6 +229,20 @@ netapp_data_motion_opts = [
                default=3600,  # One Hour
                help='The maximum time in seconds to wait for a snapmirror '
                     'release when breaking snapmirror relationships.'),
+    cfg.StrOpt('netapp_snapmirror_schedule',
+               default='hourly',  # One Hour
+               help='An interval in either minutes or hours used to update '
+                    'the SnapMirror relationship. Few valid values are: '
+                    '5min, 10min, 30min, hourly etc. The schedule at the '
+                    '"destination" host will be the one that will be '
+                    'considered when creating a new replica, or promoting '
+                    'a replica'),
+    cfg.IntOpt('netapp_snapmirror_last_transfer_size_limit',
+               min=512,
+               default=1024,  # One MB
+               help='This option set the last transfer size limit (in KB) '
+                    'of snapmirror to decide whether replica is in sync or '
+                    'out of sync.'),
     cfg.IntOpt('netapp_volume_move_cutover_timeout',
                min=0,
                default=3600,  # One Hour,
