@@ -19,6 +19,7 @@ import copy
 import ddt
 from oslo_config import cfg
 from oslo_serialization import jsonutils
+from oslo_utils import strutils
 from webob import exc
 
 from manila.api import common
@@ -38,6 +39,7 @@ CONF = cfg.CONF
 CAST_RULES_READONLY_VERSION = '2.30'
 PRE_GRADUATION_VERSION = '2.55'
 GRADUATION_VERSION = '2.56'
+PROMOTE_QUIESCE_WAIT_VERSION = '2.75'
 
 
 @ddt.ddt
@@ -396,6 +398,35 @@ class ShareReplicasApiTest(test.TestCase):
         self.mock_policy_check.assert_called_once_with(
             self.member_context, self.resource_name, 'create')
 
+    def test_create_invalid_network_id(self):
+        fake_replica, _ = self._get_fake_replica(
+            replication_type='writable')
+        req = self._get_request("2.72", False)
+        req_context = req.environ['manila.context']
+
+        body = {
+            'share_replica': {
+                'share_id': 'FAKE_SHAREID',
+                'availability_zone': 'FAKE_AZ',
+                'share_network_id': 'FAKE_NETID'
+            }
+        }
+        mock__view_builder_call = self.mock_object(
+            share_replicas.replication_view.ReplicationViewBuilder,
+            'detail_list')
+        self.mock_object(share_replicas.db, 'share_get',
+                         mock.Mock(return_value=fake_replica))
+        self.mock_object(share_replicas.db, 'share_network_get',
+                         mock.Mock(side_effect=exception.ShareNetworkNotFound(
+                                   share_network_id='FAKE_NETID')))
+
+        self.assertRaises(exc.HTTPBadRequest,
+                          self.controller.create,
+                          req, body)
+        self.assertFalse(mock__view_builder_call.called)
+        self.mock_policy_check.assert_called_once_with(
+            req_context, self.resource_name, 'create')
+
     @ddt.data(exception.AvailabilityZoneNotFound,
               exception.ReplicationException, exception.ShareBusyException)
     def test_create_exception_path(self, exception_type):
@@ -432,19 +463,25 @@ class ShareReplicasApiTest(test.TestCase):
         common.check_share_network_is_active.assert_called_once_with(
             share_network)
 
-    @ddt.data((True, PRE_GRADUATION_VERSION), (False, GRADUATION_VERSION))
+    @ddt.data((True, PRE_GRADUATION_VERSION), (False, GRADUATION_VERSION),
+              (False, "2.72"))
     @ddt.unpack
     def test_create(self, is_admin, microversion):
         fake_replica, expected_replica = self._get_fake_replica(
             replication_type='writable', admin=is_admin,
             microversion=microversion)
-        share_network = db_utils.create_share_network()
         body = {
             'share_replica': {
                 'share_id': 'FAKE_SHAREID',
                 'availability_zone': 'FAKE_AZ'
             }
         }
+        if self.is_microversion_ge(microversion, '2.72'):
+            body["share_replica"].update({"share_network_id": 'FAKE_NETID'})
+            share_network = {'id': 'FAKE_NETID'}
+        else:
+            share_network = db_utils.create_share_network()
+
         self.mock_object(share_replicas.db, 'share_get',
                          mock.Mock(return_value=fake_replica))
         self.mock_object(share.API, 'create_share_replica',
@@ -465,8 +502,12 @@ class ShareReplicasApiTest(test.TestCase):
         self.assertEqual(expected_replica, res_dict['share_replica'])
         self.mock_policy_check.assert_called_once_with(
             req_context, self.resource_name, 'create')
-        share_replicas.db.share_network_get.assert_called_once_with(
-            req_context, fake_replica['share_network_id'])
+        if self.is_microversion_ge(microversion, '2.72'):
+            share_replicas.db.share_network_get.assert_called_once_with(
+                req_context, 'FAKE_NETID')
+        else:
+            share_replicas.db.share_network_get.assert_called_once_with(
+                req_context, fake_replica['share_network_id'])
         common.check_share_network_is_active.assert_called_once_with(
             share_network)
 
@@ -640,6 +681,42 @@ class ShareReplicasApiTest(test.TestCase):
         self.mock_policy_check.assert_called_once_with(
             context, self.resource_name, 'promote')
 
+    @ddt.data(('2.74', None),
+              (PROMOTE_QUIESCE_WAIT_VERSION, None),
+              (PROMOTE_QUIESCE_WAIT_VERSION, 10),
+              (PROMOTE_QUIESCE_WAIT_VERSION, 'foobar'),
+              )
+    @ddt.unpack
+    def test_promote_quiesce_wait_time(self, microversion, time):
+        body = {'promote': {'quiesce_wait_time': time}}
+        replica, expected_replica = self._get_fake_replica(
+            replica_state=constants.REPLICA_STATE_IN_SYNC,
+            microversion=microversion)
+        self.mock_object(share_replicas.db, 'share_replica_get',
+                         mock.Mock(return_value=replica))
+        self.mock_object(share_replicas.db, 'share_network_get',
+                         mock.Mock(return_value=self.fake_share_network))
+
+        req = self._get_request(microversion=microversion)
+        allow_quiesce_wait_time = False
+        if (api_version.APIVersionRequest(microversion) >=
+                api_version.APIVersionRequest(PROMOTE_QUIESCE_WAIT_VERSION)):
+            allow_quiesce_wait_time = True
+        if time and allow_quiesce_wait_time:
+            if strutils.is_int_like(time):
+                mock_api_promote_replica_call = self.mock_object(
+                    share.API, 'promote_share_replica',
+                    mock.Mock(return_value=replica))
+                resp = self.controller.promote(req, replica['id'], body)
+                self.assertEqual(expected_replica, resp['share_replica'])
+                self.assertTrue(mock_api_promote_replica_call.called)
+            else:
+                self.assertRaises(exc.HTTPBadRequest,
+                                  self.controller.promote,
+                                  req,
+                                  replica['id'],
+                                  body)
+
     @ddt.data('index', 'detail', '_show', '_create', '_delete_share_replica',
               '_promote', 'reset_replica_state', 'reset_status', '_resync')
     def test_policy_not_authorized(self, method_name):
