@@ -88,10 +88,11 @@ def create_share(**kwargs):
         'share_server_id': None,
         'user_id': 'fake',
         'project_id': 'fake',
-        'metadata': {'fake_key': 'fake_value'},
+        'metadata': {},
         'availability_zone': 'fake_availability_zone',
         'status': constants.STATUS_CREATING,
-        'host': 'fake_host'
+        'host': 'fake_host',
+        'is_soft_deleted': False
     }
     return _create_db_row(db.share_create, share, kwargs)
 
@@ -108,7 +109,8 @@ def create_share_without_instance(**kwargs):
         'metadata': {},
         'availability_zone': 'fake_availability_zone',
         'status': constants.STATUS_CREATING,
-        'host': 'fake_host'
+        'host': 'fake_host',
+        'is_soft_deleted': False
     }
     share.update(copy.deepcopy(kwargs))
     return db.share_create(context.get_admin_context(), share, False)
@@ -212,7 +214,6 @@ def create_share_server(**kwargs):
     backend_details = kwargs.pop('backend_details', {})
     srv = {
         'host': 'host1',
-        'share_network_subnet_id': 'fake_srv_id',
         'status': constants.STATUS_ACTIVE
     }
     share_srv = _create_db_row(db.share_server_create, srv, kwargs)
@@ -298,3 +299,11 @@ def create_message(**kwargs):
         'message_level': message_levels.ERROR,
     }
     return _create_db_row(db.message_create, message_dict, kwargs)
+
+
+def create_transfer(**kwargs):
+    transfer = {'display_name': 'display_name',
+                'salt': 'salt',
+                'crypt_hash': 'crypt_hash',
+                'resource_type': constants.SHARE_RESOURCE_TYPE}
+    return _create_db_row(db.transfer_create, transfer, kwargs)
