@@ -235,38 +235,53 @@ class CephFSDriverTestCase(test.TestCase):
             self._context, self._share, access_rules, add_rules, delete_rules,
             share_server=None)
 
-    def test_ensure_share(self):
-        expected_exports = {
-            'path': '1.2.3.4,5.6.7.8:/foo/bar',
-            'is_admin_only': False,
-            'metadata': {},
+    def test_ensure_shares(self):
+        self._driver.protocol_helper.reapply_rules_while_ensuring_shares = True
+        shares = [
+            fake_share.fake_share(share_id='123', share_proto='NFS'),
+            fake_share.fake_share(share_id='456', share_proto='NFS'),
+            fake_share.fake_share(share_id='789', share_proto='NFS')
+        ]
+        export_locations = [
+            {
+                'path': '1.2.3.4,5.6.7.8:/foo/bar',
+                'is_admin_only': False,
+                'metadata': {},
+            },
+            {
+                'path': '1.2.3.4,5.6.7.8:/foo/quz',
+                'is_admin_only': False,
+                'metadata': {},
+            },
+
+        ]
+        expected_updates = {
+            shares[0]['id']: {
+                'status': constants.STATUS_ERROR,
+                'reapply_access_rules': True,
+            },
+            shares[1]['id']: {
+                'export_locations': export_locations[0],
+                'reapply_access_rules': True,
+            },
+            shares[2]['id']: {
+                'export_locations': export_locations[1],
+                'reapply_access_rules': True,
+            }
         }
+        err_message = (f"Error ENOENT: subvolume {self._share['id']} does "
+                       f"not exist")
+        expected_exception = exception.ShareBackendException(err_message)
         self.mock_object(
             self._driver, '_get_export_locations',
-            mock.Mock(return_value=expected_exports))
+            mock.Mock(side_effect=[expected_exception] + export_locations))
 
-        returned_exports = self._driver.ensure_share(self._context,
-                                                     self._share)
+        actual_updates = self._driver.ensure_shares(self._context, shares)
 
-        self._driver._get_export_locations.assert_called_once_with(self._share)
-
-        self.assertEqual(expected_exports, returned_exports)
-
-    def test_ensure_share_subvolume_not_found(self):
-        message = f"Error ENOENT: subvolume {self._share['id']} does not exist"
-        expected_exception = exception.ShareBackendException(message)
-
-        self.mock_object(
-            self._driver, '_get_export_locations',
-            mock.Mock(side_effect=expected_exception))
-
-        self.assertRaises(
-            exception.ShareResourceNotFound,
-            self._driver.ensure_share,
-            self._context,
-            self._share)
-
-        self._driver._get_export_locations.assert_called_once_with(self._share)
+        self.assertEqual(3, self._driver._get_export_locations.call_count)
+        self._driver._get_export_locations.assert_has_calls([
+            mock.call(shares[0]), mock.call(shares[1]), mock.call(shares[2])])
+        self.assertEqual(expected_updates, actual_updates)
 
     def test_delete_share(self):
         clone_status_prefix = "fs clone status"
@@ -1070,7 +1085,8 @@ class NFSProtocolHelperTestCase(test.TestCase):
             [{
                 'path': '1.2.3.4:/foo/bar',
                 'is_admin_only': False,
-                'metadata': {}
+                'metadata': {},
+                'preferred': False
             }], ret)
 
     def test_get_export_locations_with_export_ips_configured(self):
@@ -1099,16 +1115,19 @@ class NFSProtocolHelperTestCase(test.TestCase):
                     'path': '127.0.0.1:/foo/bar',
                     'is_admin_only': False,
                     'metadata': {},
+                    'preferred': False
                 },
                 {
                     'path': '[fd3f:c057:1192:1::1]:/foo/bar',
                     'is_admin_only': False,
                     'metadata': {},
+                    'preferred': False
                 },
                 {
                     'path': '[::1]:/foo/bar',
                     'is_admin_only': False,
                     'metadata': {},
+                    'preferred': False
                 },
             ], ret)
 
@@ -1394,10 +1413,12 @@ class NFSClusterProtocolHelperTestCase(test.TestCase):
             'path': '10.0.0.10:/foo/bar',
             'is_admin_only': False,
             'metadata': {},
+            'preferred': True
         }, {
             'path': '10.0.0.11:/foo/bar',
             'is_admin_only': False,
             'metadata': {},
+            'preferred': True
         }]
 
         export_locations = (
@@ -1410,6 +1431,76 @@ class NFSClusterProtocolHelperTestCase(test.TestCase):
 
         self.assertEqual(expected_export_locations, export_locations)
 
+    @ddt.data(
+        ('cephfs_ganesha_server_ip', '10.0.0.1'),
+        ('cephfs_ganesha_export_ips', ['10.0.0.2, 10.0.0.3'])
+    )
+    @ddt.unpack
+    def test_get_export_locations_ganesha_still_configured(self, opt, val):
+        cluster_info_prefix = "nfs cluster info"
+        nfs_clusterid = self._nfscluster_protocol_helper.nfs_clusterid
+        self.fake_conf.set_default(opt, val)
+
+        cluster_info_dict = {
+            "cluster_id": nfs_clusterid,
+        }
+
+        cluster_info = {"fs-manila": {
+            "virtual_ip": None,
+            "backend": [
+                {"hostname": "fake-ceph-node-1",
+                 "ip": "10.0.0.10",
+                 "port": "1010"},
+                {"hostname": "fake-ceph-node-2",
+                 "ip": "10.0.0.11",
+                 "port": "1011"}
+            ]
+        }}
+
+        driver.rados_command.return_value = json.dumps(cluster_info)
+
+        fake_cephfs_subvolume_path = "/foo/bar"
+        expected_export_locations = [{
+            'path': '10.0.0.10:/foo/bar',
+            'is_admin_only': False,
+            'metadata': {},
+            'preferred': True
+        }, {
+            'path': '10.0.0.11:/foo/bar',
+            'is_admin_only': False,
+            'metadata': {},
+            'preferred': True
+        }]
+        if isinstance(val, list):
+            for ip in val:
+                expected_export_locations.append(
+                    {
+                        'path': f'{ip}:/foo/bar',
+                        'is_admin_only': False,
+                        'metadata': {},
+                        'preferred': False
+                    }
+                )
+        else:
+            expected_export_locations.append(
+                {
+                    'path': f'{val}:/foo/bar',
+                    'is_admin_only': False,
+                    'metadata': {},
+                    'preferred': False
+                }
+            )
+
+        export_locations = (
+            self._nfscluster_protocol_helper.get_export_locations(
+                self._share, fake_cephfs_subvolume_path))
+
+        driver.rados_command.assert_called_once_with(
+            self._rados_client,
+            cluster_info_prefix, cluster_info_dict)
+
+        self.assertEqual(expected_export_locations, export_locations)
+
 
 @ddt.ddt
 class CephFSDriverAltConfigTestCase(test.TestCase):
