@@ -482,7 +482,9 @@ class DummyDriver(driver.ShareDriver):
             "reserved_percentage":
                 self.configuration.reserved_share_percentage,
             "reserved_snapshot_percentage":
-                self.configuration.reserved_share_from_snapshot_percentage
+                self.configuration.reserved_share_from_snapshot_percentage,
+            "reserved_share_extend_percentage":
+                self.configuration.reserved_share_extend_percentage
         }]
         if self.configuration.replication_domain:
             pools[0]["replication_type"] = "readable"
@@ -498,6 +500,8 @@ class DummyDriver(driver.ShareDriver):
                 self.configuration.reserved_share_percentage,
             "reserved_snapshot_percentage":
                 self.configuration.reserved_share_from_snapshot_percentage,
+            "reserved_share_extend_percentage":
+                self.configuration.reserved_share_extend_percentage,
             "snapshot_support": True,
             "create_share_from_snapshot_support": True,
             "revert_to_snapshot_support": True,
@@ -580,7 +584,7 @@ class DummyDriver(driver.ShareDriver):
 
     @slow_me_down
     def promote_replica(self, context, replica_list, replica, access_rules,
-                        share_server=None):
+                        share_server=None, quiesce_wait_time=None):
         """Promote a replica to 'active' replica state."""
         return_replica_list = []
         for r in replica_list:
