@@ -507,7 +507,8 @@ class NetAppCDOTDataMotionSessionTestCase(test.TestCase):
             self.dest_vserver, self.fake_dest_vol_name)
 
         self.dm_session.quiesce_then_abort.assert_called_once_with(
-            self.fake_src_share, self.fake_dest_share)
+            self.fake_src_share, self.fake_dest_share,
+            quiesce_wait_time=None)
 
         self.mock_dest_client.mount_volume.assert_called_once_with(
             self.fake_dest_vol_name)
@@ -524,7 +525,8 @@ class NetAppCDOTDataMotionSessionTestCase(test.TestCase):
             self.dest_vserver, self.fake_dest_vol_name)
 
         self.dm_session.quiesce_then_abort.assert_called_once_with(
-            self.fake_src_share, self.fake_dest_share)
+            self.fake_src_share, self.fake_dest_share,
+            quiesce_wait_time=None)
 
         self.assertFalse(self.mock_dest_client.mount_volume.called)
 
@@ -535,7 +537,8 @@ class NetAppCDOTDataMotionSessionTestCase(test.TestCase):
                                          self.fake_dest_share)
 
         self.dm_session.quiesce_then_abort.assert_called_once_with(
-            self.fake_src_share, self.fake_dest_share)
+            self.fake_src_share, self.fake_dest_share,
+            quiesce_wait_time=None)
 
         self.mock_dest_client.break_snapmirror_vol.assert_called_once_with(
             self.source_vserver, self.fake_src_vol_name,
@@ -544,6 +547,39 @@ class NetAppCDOTDataMotionSessionTestCase(test.TestCase):
         self.mock_dest_client.mount_volume.assert_called_once_with(
             self.fake_dest_vol_name)
 
+    @ddt.data(None, 2, 30)
+    def test_quiesce_then_abort_wait_time(self, wait_time):
+        self.mock_object(time, 'sleep')
+        mock_get_snapmirrors = mock.Mock(
+            return_value=[{'relationship-status': "transferring"}])
+        self.mock_object(self.mock_dest_client, 'get_snapmirrors',
+                         mock_get_snapmirrors)
+        mock_backend_config = na_fakes.create_configuration()
+        mock_backend_config.netapp_snapmirror_quiesce_timeout = 10
+        self.mock_object(data_motion, 'get_backend_configuration',
+                         mock.Mock(return_value=mock_backend_config))
+
+        self.dm_session.quiesce_then_abort(self.fake_src_share,
+                                           self.fake_dest_share,
+                                           quiesce_wait_time=wait_time)
+
+        self.mock_dest_client.get_snapmirrors.assert_called_with(
+            source_vserver=self.source_vserver,
+            dest_vserver=self.dest_vserver,
+            source_volume=self.fake_src_vol_name,
+            dest_volume=self.fake_dest_vol_name,
+            desired_attributes=['relationship-status', 'mirror-state']
+        )
+
+        call_count = self.mock_dest_client.get_snapmirrors.call_count
+        if wait_time:
+            if wait_time > 5:
+                self.assertEqual(wait_time / 5, call_count)
+            else:
+                self.assertEqual(1, call_count)
+        else:
+            self.assertEqual(2, call_count)
+
     def test_quiesce_then_abort_timeout(self):
         self.mock_object(time, 'sleep')
         mock_get_snapmirrors = mock.Mock(
@@ -765,7 +801,9 @@ class NetAppCDOTDataMotionSessionTestCase(test.TestCase):
                                 'mirror-state',
                                 'source-vserver',
                                 'source-volume',
-                                'last-transfer-end-timestamp']
+                                'last-transfer-end-timestamp',
+                                'last-transfer-size',
+                                'last-transfer-error']
         )
         self.assertEqual(1, self.mock_dest_client.get_snapmirrors.call_count)
 
@@ -1179,3 +1217,57 @@ class NetAppCDOTDataMotionSessionTestCase(test.TestCase):
         src_mock_client.release_snapmirror_vol.assert_called_once_with(
             fake.VSERVER1, fake.SHARE_NAME, fake.VSERVER2, fake.SHARE_NAME2,
             relationship_info_only=False)
+
+    @ddt.data([{'id': 'src_share'}, {'id': 'dst_share'}],
+              [{'id': 'dst_share'}])
+    def test_cleanup_previous_snapmirror_relationships(self, replica_list):
+        mock_src_client = mock.Mock()
+        src_backend_info = ('src_share', 'src_vserver', 'src_backend')
+        dst_backend_info = ('dst_share', 'dst_vserver', 'dst_backend')
+        self.mock_object(self.dm_session, 'get_backend_info_for_share',
+                         mock.Mock(side_effect=[src_backend_info,
+                                                dst_backend_info]))
+        self.mock_object(data_motion, 'get_client_for_backend',
+                         mock.Mock(return_value=mock_src_client))
+        self.mock_object(mock_src_client, 'release_snapmirror_vol')
+
+        result = self.dm_session.cleanup_previous_snapmirror_relationships(
+            {'id': 'src_share'}, replica_list)
+
+        data_motion.get_client_for_backend.assert_called_once_with(
+            'src_backend', vserver_name='src_vserver')
+        self.dm_session.get_backend_info_for_share.assert_has_calls([
+            mock.call({'id': 'src_share'}),
+            mock.call({'id': 'dst_share'})
+        ])
+        mock_src_client.release_snapmirror_vol.assert_called_once_with(
+            'src_vserver', 'src_share', 'dst_vserver', 'dst_share')
+
+        self.assertIsNone(result)
+
+    @ddt.data(netapp_api.NaApiError(),
+              netapp_api.NaApiError(code=netapp_api.EOBJECTNOTFOUND),
+              netapp_api.NaApiError(code=netapp_api.ESOURCE_IS_DIFFERENT),
+              netapp_api.NaApiError(code='some_random_code',
+                                    message="(entry doesn't exist)"),
+              netapp_api.NaApiError(code='some_random_code',
+                                    message='(actually, entry does exist!)'))
+    def test_cleanup_previous_snapmirror_relationships_does_not_exist(
+            self, release_exception):
+        mock_src_client = mock.Mock()
+        self.mock_object(self.dm_session, 'get_backend_info_for_share',
+                         mock.Mock(return_value=(
+                             mock.Mock(), mock.Mock(), mock.Mock())))
+        self.mock_object(data_motion, 'get_client_for_backend',
+                         mock.Mock(return_value=mock_src_client))
+        self.mock_object(mock_src_client, 'release_snapmirror_vol',
+                         mock.Mock(side_effect=release_exception))
+
+        replica = {'id': 'src_share'}
+        replica_list = [replica, {'id': 'dst_share'}]
+
+        result = self.dm_session.cleanup_previous_snapmirror_relationships(
+            replica, replica_list)
+
+        mock_src_client.release_snapmirror_vol.assert_called()
+        self.assertIsNone(result)
