@@ -19,7 +19,6 @@ from oslo_serialization import jsonutils
 from manila.common import constants
 import manila.tests.share.drivers.netapp.fakes as na_fakes
 
-NO_SNAPRESTORE_LICENSE = '"SnapRestore" is not licensed in the cluster.'
 CLUSTER_NAME = 'fake_cluster'
 CLUSTER_NAME_2 = 'fake_cluster_2'
 BACKEND_NAME = 'fake_backend_name'
@@ -65,6 +64,8 @@ FREE_CAPACITY = 10000000000
 TOTAL_CAPACITY = 20000000000
 AGGREGATE = 'manila_aggr_1'
 AGGREGATES = ('manila_aggr_1', 'manila_aggr_2')
+AGGR_POOL_NAME = 'manila_aggr_1'
+FLEXGROUP_POOL_NAME = 'flexgroup_pool'
 ROOT_AGGREGATES = ('root_aggr_1', 'root_aggr_2')
 ROOT_VOLUME_AGGREGATE = 'manila1'
 ROOT_VOLUME = 'root'
@@ -86,6 +87,10 @@ MANILA_HOST_NAME_2 = '%(host)s@%(backend)s#%(pool)s' % {
     'host': HOST_NAME, 'backend': BACKEND_NAME, 'pool': POOL_NAME_2}
 MANILA_HOST_NAME_3 = '%(host)s@%(backend)s#%(pool)s' % {
     'host': HOST_NAME, 'backend': BACKEND_NAME_2, 'pool': POOL_NAME_2}
+MANILA_HOST_NAME_AGGR = '%(host)s@%(backend)s#%(pool)s' % {
+    'host': HOST_NAME, 'backend': BACKEND_NAME, 'pool': AGGR_POOL_NAME}
+MANILA_HOST_NAME_FLEXG_AGGR = '%(host)s@%(backend)s#%(pool)s' % {
+    'host': HOST_NAME, 'backend': BACKEND_NAME, 'pool': FLEXGROUP_POOL_NAME}
 SERVER_HOST = '%(host)s@%(backend)s' % {
     'host': HOST_NAME, 'backend': BACKEND_NAME}
 SERVER_HOST_2 = '%(host)s@%(backend)s' % {
@@ -140,6 +145,46 @@ SHARE = {
     'share_id': SHARE_ID,
 }
 
+SHARE_2 = {
+    'id': SHARE_ID,
+    'host': MANILA_HOST_NAME_AGGR,
+    'project_id': TENANT_ID,
+    'name': SHARE_NAME,
+    'size': SHARE_SIZE,
+    'share_proto': 'fake',
+    'share_type_id': 'fake_share_type_id',
+    'share_network_id': '5dfe0898-e2a1-4740-9177-81c7d26713b0',
+    'share_server_id': '7e6a2cc8-871f-4b1d-8364-5aad0f98da86',
+    'network_info': {
+        'network_allocations': [{'ip_address': 'ip'}]
+    },
+    'replica_state': constants.REPLICA_STATE_ACTIVE,
+    'status': constants.STATUS_AVAILABLE,
+    'share_server': None,
+    'encrypt': False,
+    'share_id': SHARE_ID,
+}
+
+SHARE_FLEXGROUP = {
+    'id': SHARE_ID,
+    'host': MANILA_HOST_NAME_FLEXG_AGGR,
+    'project_id': TENANT_ID,
+    'name': SHARE_NAME,
+    'size': SHARE_SIZE,
+    'share_proto': 'fake',
+    'share_type_id': 'fake_share_type_id',
+    'share_network_id': '5dfe0898-e2a1-4740-9177-81c7d26713b0',
+    'share_server_id': '7e6a2cc8-871f-4b1d-8364-5aad0f98da86',
+    'network_info': {
+        'network_allocations': [{'ip_address': 'ip'}]
+    },
+    'replica_state': constants.REPLICA_STATE_ACTIVE,
+    'status': constants.STATUS_AVAILABLE,
+    'share_server': None,
+    'encrypt': False,
+    'share_id': SHARE_ID,
+}
+
 SHARE_INSTANCE = {
     'id': SHARE_INSTANCE_ID,
     'share_id': SHARE_ID,
@@ -515,6 +560,7 @@ NETWORK_INFO = {
     'neutron_net_id': '4eff22ca-5ad2-454d-a000-aadfd7b40b39',
     'neutron_subnet_id': '62bf1c2c-18eb-421b-8983-48a6d39aafe0',
     'segmentation_id': '1000',
+    'network_type': 'vlan'
 }
 NETWORK_INFO_LIST = [NETWORK_INFO]
 NETWORK_INFO_NETMASK = '255.255.255.0'
@@ -643,6 +689,7 @@ CDOT_SNAPSHOT = {
     'busy': False,
     'owners': set(),
     'access-time': SNAPSHOT_ACCESS_TIME,
+    'locked_by_clone': False,
 }
 
 CDOT_SNAPSHOT_BUSY_VOLUME_CLONE = {
@@ -651,6 +698,7 @@ CDOT_SNAPSHOT_BUSY_VOLUME_CLONE = {
     'busy': True,
     'owners': {'volume clone'},
     'access-time': SNAPSHOT_ACCESS_TIME,
+    'locked_by_clone': True,
 }
 
 CDOT_SNAPSHOT_BUSY_SNAPMIRROR = {
@@ -659,6 +707,7 @@ CDOT_SNAPSHOT_BUSY_SNAPMIRROR = {
     'busy': True,
     'owners': {'snapmirror'},
     'access-time': SNAPSHOT_ACCESS_TIME,
+    'locked_by_clone': False,
 }
 
 CDOT_CLONE_CHILD_1 = 'fake_child_1'
@@ -871,8 +920,6 @@ AGGREGATE_CAPACITIES = {
     }
 }
 
-FLEXGROUP_POOL_NAME = 'flexgroup_pool'
-
 FLEXGROUP_POOL_AGGR = [AGGREGATES[0], AGGREGATES[1]]
 
 FLEXGROUP_POOL_OPT = {
@@ -970,6 +1017,7 @@ POOLS = [
         'allocated_capacity_gb': 2.2,
         'reserved_percentage': 5,
         'reserved_snapshot_percentage': 2,
+        'reserved_share_extend_percentage': 2,
         'max_over_subscription_ratio': 2.0,
         'dedupe': [True, False],
         'compression': [True, False],
@@ -997,6 +1045,7 @@ POOLS = [
         'allocated_capacity_gb': 4.0,
         'reserved_percentage': 5,
         'reserved_snapshot_percentage': 2,
+        'reserved_share_extend_percentage': 2,
         'max_over_subscription_ratio': 2.0,
         'dedupe': [True, False],
         'compression': [True, False],
@@ -1029,6 +1078,7 @@ POOLS_VSERVER_CREDS = [
         'allocated_capacity_gb': 0.0,
         'reserved_percentage': 5,
         'reserved_snapshot_percentage': 2,
+        'reserved_share_extend_percentage': 2,
         'max_over_subscription_ratio': 2.0,
         'dedupe': [True, False],
         'compression': [True, False],
@@ -1051,6 +1101,7 @@ POOLS_VSERVER_CREDS = [
         'allocated_capacity_gb': 0.0,
         'reserved_percentage': 5,
         'reserved_snapshot_percentage': 2,
+        'reserved_share_extend_percentage': 2,
         'max_over_subscription_ratio': 2.0,
         'dedupe': [True, False],
         'compression': [True, False],
@@ -1643,6 +1694,7 @@ CIFS_SECURITY_SERVICE = {
     'domain': 'fake_domain',
     'dns_ip': 'fake_dns_ip',
     'server': 'fake_server',
+    'default_ad_site': None,
 }
 
 CIFS_SECURITY_SERVICE_2 = {
@@ -1654,7 +1706,21 @@ CIFS_SECURITY_SERVICE_2 = {
     'domain': 'fake_domain_2',
     'dns_ip': 'fake_dns_ip_2',
     'server': 'fake_server_2',
+    'default_ad_site': None,
 }
+
+CIFS_SECURITY_SERVICE_3 = {
+    'id': 'fake_id_3',
+    'type': 'active_directory',
+    'password': 'fake_password_3',
+    'user': 'fake_user_3',
+    'ou': 'fake_ou_3',
+    'domain': 'fake_domain_3',
+    'dns_ip': 'fake_dns_ip_3',
+    'default_ad_site': 'fake_default_ad_site',
+    'server': None
+}
+
 LDAP_LINUX_SECURITY_SERVICE = {
     'id': 'fake_id',
     'type': 'ldap',
@@ -1809,6 +1875,7 @@ def get_config_cmode():
     config.local_conf.set_override('share_backend_name', BACKEND_NAME)
     config.reserved_share_percentage = 5
     config.reserved_share_from_snapshot_percentage = 2
+    config.reserved_share_extend_percentage = 2
     config.max_over_subscription_ratio = 2.0
     config.netapp_login = CLIENT_KWARGS['username']
     config.netapp_password = CLIENT_KWARGS['password']
